@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-
+import re
 import ROOT
 import numpy as np
 from array import array
@@ -100,18 +100,27 @@ def main( *args ):
     # print(  shape[-1] )
     # print( [ str(i) for i in range(0,10) ] )
 
+
+
     # POL0-9
+    polorder = 1
     if (len(shape)==4) and (shape.find("pol")==0) and ( shape[-1] in [ str(i) for i in range(0,10) ] ):
-        print("i... POLi model shape  detected")
+        print("i... POLi model shape  DEMANDED")
         polorder = int(shape[-1])
         shape = "polall"
 
     # POC0-9 - chebyshev
     if (len(shape)==4) and (shape.find("poc")==0) and ( shape[-1] in [ str(i) for i in range(0,10) ] ):
-        print("i... POLi model shape  detected")
+        print("i... POLi model shape  DEMANDED")
         polorder = int(shape[-1])
         shape = "pocall"
 
+    # np exp  np log - logxy
+    if (len(shape)==6) and (shape.find("logxy")==0) and ( shape[-1] in [ str(i) for i in range(0,10) ] ):
+        print("i... LOGXYi model  shape  DEMANDED")
+        polorder = int(shape[-1])
+        shape = "logxy"
+
     model_name = f"model_{shape}"
     module = prun.import_module( model_name )
 
@@ -233,19 +242,32 @@ def main( *args ):
 
     # --- I can output the results.  I do it for : gpol1
     #print(type(yf))
-
+    xf10 = None
+    yf10 = None
     if type(yf) is np.ndarray:
         print("")
+        yf10 = yf
+        xf10 = x
 
     elif type(yf) is tuple: # ------------ i wanted to get 3 functions (fit,low,high)
         yf,yf_l,yf_h=yf[0],yf[1],yf[2]
+        yf10 = yf
+        xf10 = x
 
-    elif  type(yf) is dict:
-        print("i... full dict of data return")
+
+    elif  type(yf) is dict: #*------------------------ ALL DATA
+        #print("i... full dict of data return")
         data_dict = yf
+
         #yf_l = data_dict['yf_l']
         #yf_h = data_dict['yf_h']
         yf   = data_dict['yf']
+        yf10 = yf
+        xf10 = x
+
+        if 'yf10' in data_dict:
+            yf10   = data_dict['yf10']
+            xf10   = data_dict['xf10']
 
     else:
         print("X... I am watching the output of the fit module. Unknown. Stop") # just yf values to plot
@@ -273,10 +295,12 @@ def main( *args ):
 
     cmain.SetFillColor(19)
     cmain.Clear()
-    print("i... div a new /fitresult/ canvas")
+    #print("i... div a new /fitresult/ canvas")
     cmain.Divide(1,2) # div canvas
     cmain.cd(1)
 
+
+
     ####g_xy = ROOT.TGraph( len(x) , x.flatten("C"), yf.flatten("C") )
     g_orig.SetMarkerStyle(7) # small circle , no lines...
 
@@ -294,7 +318,7 @@ def main( *args ):
     #print(type(yf), len(yf) , yf)
 
 
-    # --------------------- result plotted ---------------
+    # --------------------- resulting fit plotted ---------------
     magenta = 3
     if ishisto:
         #print(g_orig.GetXaxis().GetXmin()  , g_orig.GetXaxis().GetXmax() )
@@ -302,6 +326,7 @@ def main( *args ):
         calb =  g_orig.GetXaxis().GetXmax() - cala*g_orig.GetNbinsX()
         #print(x)
         x = cala*x + calb
+        xf10 = cala*xf10 + calb # I have a problem with calibration
 
         data_dict["cala"] = cala
         data_dict["calb"] = calb
@@ -333,14 +358,46 @@ def main( *args ):
 
         #print(x)
         #print(cala,calb)
-    gf = ROOT.TGraph( len(x) , x.flatten("C"), yf.flatten("C") )
-    gf.SetLineColor(magenta) # 5 yellow 6 magenta
-    gf.SetLineWidth(2)
+    #-----------------------------------
+
+    if xf10 is None:
+        gf = ROOT.TGraph( len(x) , x.flatten("C"), yf.flatten("C") )
+    else:
+        #print(xf10)
+        #print(yf10)
+        gf = ROOT.TGraph( len(xf10) , xf10.flatten("C"), yf10.flatten("C") )
+        # specific for efficiency
+        try:
+            position = os.path.splitext( g_orig.GetTitle() )[0]
+            position = int( re.findall("\d+", position)[0] )
+            print("i... Title of graph is ",g_orig.GetTitle() , position )
+            # writing out tab; with all points --- for efficiency---
+            with open(f"out{position}.tab", "w" ) as f:
+                #f.write( "\n".join( str(yf10).strip("][").split() )+"\n"  )
+                ar2d = np.vstack( (xf10, yf10) ).T
+                #print(ar2d)
+                np.savetxt( f, ar2d )
+            with open("oparams.txt","a") as f:
+                f.write( f"{position}  {data_dict['a']} {data_dict['da']}  {data_dict['b']}   {data_dict['db']}  {data_dict['c']}  {data_dict['dc']}  {data_dict['e']} {data_dict['de']}\n" )
+        except:
+            print(" ... no model output was saved (pr_fit)")
+    #print(data_dict.keys())
+    #gf.Print()
+    gf.SetLineColor(magenta) # red2/green3 ...   5 yellow 6 magenta
+    gf.SetMarkerColor(magenta) # red2/green3 ...   5 yellow 6 magenta
+    gf.SetMarkerStyle(7) # red2/green3 ...   5 yellow 6 magenta
+    gf.SetLineWidth(1)
     #gf.SetFillStyle(3004)
     #gf.SetFillColor(6)
     #gf.SetFillColorAlpha( 6, 0.05)
     #gf.Draw("sameLF") # i liked to fill gaus F
-    gf.Draw("sameL")
+    gf.Draw("samePL")
+    if ('data_dict' in locals()) and ( 'logy' in data_dict):
+        if data_dict['logy']:
+            ROOT.gPad.SetLogy()
+    if('data_dict' in locals()) and ( 'logx' in data_dict):
+        if data_dict['logx']:
+            ROOT.gPad.SetLogx()
 
 
     # if not ("yf_l" in locals()):
@@ -388,7 +445,7 @@ def main( *args ):
     #print(f"NEWTITLE={newtitle}")
     gf_diff.SetTitle( newtitle)
     gf_diff.SetMarkerStyle(7) # small circle , no lines...
-    gf_diff.SetLineColor(4)
+    gf_diff.SetLineColor(4) #
     gf_diff.Draw("PAW")
 
 
