@@ -74,7 +74,8 @@ def listpy():
         print("X... NO python FILES available (listpy)")
         return None
     # files = [x for x in files if x.find("pr_model_")!=0] # models- I exclude?
-    print(f"i... modules available in REPO:\n          {[ x.rstrip('.py').lstrip('pr_') for x in files]}")
+    corenames = [ os.path.splitext(x)[0].split("pr_")[1] for x in files]
+    print(f"i... modules available in REPO:\n          {corenames}")
     files = [ tgt2+"/"+x for x in files ]
     #- GO back from repo
     os.chdir( dirnow )
@@ -87,7 +88,8 @@ def listpy():
         # return None
         #files = filescur
     else:
-        print(f"i... modules available in CURR:\n          {[ x.rstrip('.py').lstrip('pr_') for x in filescur]}")
+        corenames = [ os.path.splitext(x)[0].split("pr_")[1] for x in filescur]
+        print(f"i... modules available in CURR:\n          {corenames}")
         # files = [x for x in files if x.find("pr_model_")!=0] # models- I exclude?
         files =  files + filescur
 
